import { select, arc } from 'd3';

const svg = d3.select('#member-salary-comparison');

  const width = +svg.attr('width');
  const height = +svg.attr('height');

  // https://coolors.co/eafbfd-3280a7-57c2e6-004177-f7df45
  const color1 = "#EAFBFD";
  const color_actual_member_circle = "#3280A7";
  const color_market_salary = "#57C2E6";
  const color_circle_selected = "#004177";
  const color_circle = "#F7DF45";
	const circleRadius = 20;

  const render = (data, dataCurrentUser) => {
    const yValue = d => d.amount;

    const margin = { top: 20, right: 40, bottom: 20, left: 120 };
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;

    const xScale = d3.scaleLinear()
      .domain([0, 1])
      .range([10, innerWidth - 10])

    const yScale = d3.scaleLinear()
      .domain([0, 100000])
      .range([innerHeight, margin.top])

    const g = svg.append('g')
      .attr('transform', `translate(${margin.left},${margin.top})`);


    const yAxis = d3.axisLeft(yScale)
      .tickSize(-innerWidth)
      .tickPadding(10);

    const yAxisG = g.append('g').call(yAxis);
    yAxisG.selectAll('.domain').remove();
    
    function handleMouseOver(d, i) {
      const circle = d3.select(this);
      
      circle
        .attr('r', circleRadius * 2)
        .attr('fill', color_circle_selected);

      const tipX = circle.attr('cx');
      const tipY = circle.attr('cy') - 60;

      const gTip = g.append("g")
        .attr('transform', `translate(${tipX},${tipY})`)
        .attr('id', `tip-${i}`)
        .attr('class', 'chart-tip')

      gTip.append('rect')
        .attr('class', 'chart-tip-rect')
        .attr('width', 100)
        .attr('height', 50)
        .attr('y', -20)
        .attr('x', -10)
        .attr('fill', "yellow")

      gTip.append('text')
        .attr('class', 'chart-tip-amount')
        .attr('y', 0)
        .text(d.content.amount)
    }

    function handleMouseOut(d, i) {
      d3.select(this)
        .attr('fill', color_circle)
        .attr('r', circleRadius);

      d3.select(`#tip-${i}`).remove();  // Remove text location
    }

    g.selectAll("circle")
      .data(data)
      .enter()
      .append("circle")
      .attr("data-amount", d => d.amount)
      .attr("r", circleRadius)
      .attr("fill-opacity", 0.6)
      .attr("cx", d => xScale(Math.random()))
      .attr("cy", d => yScale(yValue(d)))
      .attr("fill", color_circle)
    	.on("mouseover", handleMouseOver)
      .on("mouseout", handleMouseOut)

      g.append("circle")
        .attr("data-amount", dataCurrentUser.content.amount)
        .attr("r", circleRadius)
        .attr("fill-opacity", 0.6)
        .attr("cx", xScale(0.5))
        .attr("cy", yScale(dataCurrentUser.content.amount))
        .attr("fill", color_actual_member_circle)
  }

  var data = [
  {
    "member_uuid": "4c27e910-0f56-0137-bde7-04383552e34a",
    "date": "2018-06-30 22:00:00",
    "content": {
      "amount": 48000
    }
  },
  {
    "member_uuid": "4c336770-0f56-0137-bdeb-04383552e34a",
    "date": "2017-11-30 23:00:00",
    "content": {
      "amount": 45000
    }
  },
  {
    "member_uuid": "4c3aea30-0f56-0137-bdee-04383552e34a",
    "date": "2017-10-31 23:00:00",
    "content": {
      "amount": 60000
    }
  },
  {
    "member_uuid": "4c42b0e0-0f56-0137-bdf2-04383552e34a",
    "date": "2018-06-30 22:00:00",
    "content": {
      "amount": 35000
    }
  },
  {
    "member_uuid": "4c50fd60-0f56-0137-bdf9-04383552e34a",
    "date": "2018-08-31 22:00:00",
    "content": {
      "amount": 60000
    }
  },
  {
    "member_uuid": "4c5e0500-0f56-0137-be00-04383552e34a",
    "date": "2018-12-31 23:00:00",
    "content": {
      "amount": 55000
    }
  },
  {
    "member_uuid": "4c690330-0f56-0137-be06-04383552e34a",
    "date": "2018-06-30 22:00:00",
    "content": {
      "amount": 60000
    }
  },
  {
    "member_uuid": "4c7122b0-0f56-0137-be0a-04383552e34a",
    "date": "2018-09-30 22:00:00",
    "content": {
      "amount": 29400
    }
  },
  {
    "member_uuid": "4c778b20-0f56-0137-be0d-04383552e34a",
    "date": "2017-10-01 22:00:00",
    "content": {
      "amount": 70000
    }
  },
  {
    "member_uuid": "4c7dfae0-0f56-0137-be10-04383552e34a",
    "date": "2018-06-30 22:00:00",
    "content": {
      "amount": 60000
    }
  },
  {
    "member_uuid": "4c845ec0-0f56-0137-be13-04383552e34a",
    "date": "2018-05-13 22:00:00",
    "content": {
      "amount": 35000
    }
  },
  {
    "member_uuid": "4c8a96f0-0f56-0137-be16-04383552e34a",
    "date": "2018-05-20 22:00:00",
    "content": {
      "amount": 70000
    }
  },
  {
    "member_uuid": "4c90de80-0f56-0137-be19-04383552e34a",
    "date": "2018-02-11 23:00:00",
    "content": {
      "amount": 75000
    }
  },
  {
    "member_uuid": "4c975d50-0f56-0137-be1c-04383552e34a",
    "date": "2019-01-06 23:00:00",
    "content": {
      "amount": 42000
    }
  },
  {
    "member_uuid": "4c9db000-0f56-0137-be1f-04383552e34a",
    "date": "2019-02-17 23:00:00",
    "content": {
      "amount": 45000
    }
  },
  {
    "member_uuid": "4ca61d40-0f56-0137-be23-04383552e34a",
    "date": "2018-08-31 22:00:00",
    "content": {
      "amount": 75000
    }
  }
];

  data.forEach(d => {
    d.amount = +d.content.amount
  });

    var dataCurrentUser = {
  "member_uuid": "4c490d00-0f56-0137-bdf5-04383552e34a",
  "date": "2019-01-06 23:00:00",
  "content": {
    "amount": 65000
  }
};

  render(data, dataCurrentUser);